Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Mirage_protocols.TCPSourceA TCP stack that can send and receive reliable streams using the TCP protocol.
The type for TCP write errors.
The type for memory buffers.
The type for IP address representations.
The type for input function continuation to pass onto the underlying IP stack. This will normally be a NOOP for a conventional kernel, but a direct implementation will parse the buffer.
A flow represents the state of a single TCPv4 stream that is connected to an endpoint.
include Mirage_flow.S
with type 'a io := 'a io
and type buffer := buffer
and type flow := flow
and type error := error
and type write_error := write_errorpp_write_error is the pretty-printer for write errors.
read flow blocks until some data is available and returns a fresh buffer containing it.
The returned buffer will be of a size convenient to the flow implementation, but will always have at least 1 byte.
If the remote endpoint calls close then calls to read will keep returning data until all the in-flight data has been read. read flow will return `Eof when the remote endpoint has called close and when there is no more in-flight data.
write flow buffer writes a buffer to the flow. There is no indication when the buffer has actually been read and, therefore, it must not be reused. The contents may be transmitted in separate packets, depending on the underlying transport. The result Ok () indicates success, Error `Closed indicates that the connection is now closed and therefore the data could not be written. Other errors are possible.
writev flow buffers writes a sequence of buffers to the flow. There is no indication when the buffers have actually been read and, therefore, they must not be reused. The result Ok () indicates success, Error `Closed indicates that the connection is now closed and therefore the data could not be written. Other errors are possible.
close flow flushes all pending writes and signals the remote endpoint that there will be no future writes. Once the remote endpoint has read all pending data, it is expected that calls to read on the remote return `Eof.
Note it is still possible for the remote endpoint to write to the flow and for the local endpoint to call read. This state where the local endpoint has called close but the remote endpoint has not called close is similar to that of a half-closed TCP connection or a Unix socket after shutdown(SHUTDOWN_WRITE).
close flow waits until the remote endpoint has also called close before returning. At this point no data can flow in either direction and resources associated with the flow can be freed.
Get the destination IPv4 address and destination port that a flow is currently connected to.
write_nodelay flow buffer writes the contents of buffer to the flow. The thread blocks until all data has been successfully transmitted to the remote endpoint. Buffering within the stack is minimized in this mode. Note that this API will change in a future revision to be a per-flow attribute instead of a separately exposed function.
writev_nodelay flow buffers writes the contents of buffers to the flow. The thread blocks until all data has been successfully transmitted to the remote endpoint. Buffering within the stack is minimized in this mode. Note that this API will change in a future revision to be a per-flow attribute instead of a separately exposed function.
val create_connection :
?keepalive:Keepalive.t ->
t ->
(ipaddr * int) ->
(flow, error) result iocreate_connection ~keepalive t (addr,port) opens a TCPv4 connection to the specified endpoint.
If the optional argument ?keepalive is provided then TCP keep-alive messages will be sent to the server when the connection is idle. If no responses are received then eventually the connection will be disconnected: read will return Ok `Eof and write will return Error `Closed
type listener = {process : flow -> unit io;process a connected flow
*)keepalive : Keepalive.t option;optional TCP keepalive configuration
*)}A TCP listener on a particular port
input t listeners returns an input function continuation to be passed to the underlying IP stack.
When the stack receives a TCP SYN (i.e. a connection request) to a particular port, it will evaluate listeners port:
listeners port is None, the input function will return an RST to refuse the connection.listeners port is Some listener then the connection will be accepted and the resulting flow will be processed by listener.process. If listener.keepalive is Some configuration then the TCP keep-alive configuration will be applied before calling listener.process.