package mirage-protocols

  1. Overview
  2. Docs

Module Mirage_protocolsSource

MirageOS signatures for network protocols

v3.1.0

Ethernet layer

Sourcemodule Ethernet : sig ... end
Sourcemodule type ETHERNET = sig ... end

Ethernet (IEEE 802.3) is a widely used data link layer. The hardware is usually a twisted pair or fibre connection, on the software side it consists of an Ethernet header where source and destination mac addresses, and a type field, indicating the type of the next layer, are present. The Ethernet layer consists of network card mac address and MTU information, and provides decapsulation and encapsulation.

IP stack

Sourcemodule Ip : sig ... end

IP errors.

Sourcemodule type IP = sig ... end

An Internet Protocol (IP) stack reassembles IP fragments into packets, removes the IP header, and on the sending side fragments overlong payload and inserts IP headers.

ARP

Sourcemodule Arp : sig ... end

Arp error.

Sourcemodule type ARP = sig ... end
Sourcemodule type IPV4 = sig ... end
Sourcemodule type IPV6 = sig ... end

No Icmp module, as there are no exposed error polymorphic variants

Sourcemodule type ICMP = sig ... end
Sourcemodule type ICMPV4 = sig ... end

UDP stack

No Udp module, as there are no exposed error polymorphic variants

Sourcemodule type UDP = sig ... end

TCP stack

Sourcemodule Tcp : sig ... end

TCP errors.

Sourcemodule Keepalive : sig ... end

Configuration for TCP keep-alives. Keep-alive messages are probes sent on an idle connection. If no traffic is received after a certain number of probes are sent, then the connection is assumed to have been lost.

Sourcemodule type TCP = sig ... end

A TCP stack that can send and receive reliable streams using the TCP protocol.