Page
Library
Module
Module type
Parameter
Class
Class type
Mirage_protocolsSourceMirageOS signatures for network protocols
v3.1.0
Ethernet (IEEE 802.3) is a widely used data link layer. The hardware is usually a twisted pair or fibre connection, on the software side it consists of an Ethernet header where source and destination mac addresses, and a type field, indicating the type of the next layer, are present. The Ethernet layer consists of network card mac address and MTU information, and provides decapsulation and encapsulation.
An Internet Protocol (IP) stack reassembles IP fragments into packets, removes the IP header, and on the sending side fragments overlong payload and inserts IP headers.
No Icmp module, as there are no exposed error polymorphic variants
No Udp module, as there are no exposed error polymorphic variants
Configuration for TCP keep-alives. Keep-alive messages are probes sent on an idle connection. If no traffic is received after a certain number of probes are sent, then the connection is assumed to have been lost.