Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Mirage_protocols.UDPSourceThe type for UDP errors.
The type for memory buffers.
The type for an IP address representations.
The type for input function continuation to pass onto the underlying IP stack. This will normally be a NOOP for a conventional kernel, but a direct implementation will parse the buffer.
The type for callback functions that adds the UDP metadata for src and dst IP addresses, the src_port of the connection and the buffer payload of the datagram.
input listeners t demultiplexes incoming datagrams based on their destination port. The listeners callback will either return a concrete handler or a None, which results in the datagram being dropped.
val write :
?src_port:int ->
?ttl:int ->
dst:ipaddr ->
dst_port:int ->
t ->
buffer ->
(unit, error) result iowrite ~src_port ~ttl ~dst ~dst_port udp data is a thread that writes data from an optional src_port to a dst and dst_port IPv4 address pair. An optional time-to-live (ttl) is passed through to the IP stack.